@@ -19,35 +19,35 @@
     <message>
         <location filename="../mainwindow.ui" line="105"/>
         <source>Add User Account</source>
-        <translation type="unfinished"/>
+        <translation>Додати обліковий запис користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="132"/>
         <source>Reenter password for new user</source>
-        <translation type="unfinished"/>
+        <translation>Повторно введіть пароль для нового користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="141"/>
         <source>confirm password</source>
-        <translation type="unfinished"/>
+        <translation>підтвердіть пароль</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="157"/>
         <location filename="../mainwindow.ui" line="1201"/>
         <source>Username of new user</source>
-        <translation type="unfinished"/>
+        <translation>Ім&apos;я нового користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="160"/>
         <source>User login name:</source>
-        <translation type="unfinished"/>
+        <translation>Ім&apos;я користувача для входу:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="176"/>
         <location filename="../mainwindow.ui" line="456"/>
         <location filename="../mainwindow.ui" line="1220"/>
         <source>Enter username of new user</source>
-        <translation type="unfinished"/>
+        <translation>Введіть ім&apos;я нового користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="182"/>
@@ -59,17 +59,17 @@
         <location filename="../mainwindow.ui" line="198"/>
         <location filename="../mainwindow.ui" line="242"/>
         <source>Password for new user</source>
-        <translation type="unfinished"/>
+        <translation>Пароль для нового користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="201"/>
         <source>User password:</source>
-        <translation type="unfinished"/>
+        <translation>Пароль користувача:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="217"/>
         <source>Enter password for new user</source>
-        <translation type="unfinished"/>
+        <translation>Введіть пароль для нового користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="226"/>
@@ -84,12 +84,12 @@
     <message>
         <location filename="../mainwindow.ui" line="280"/>
         <source>Delete User Account</source>
-        <translation type="unfinished"/>
+        <translation>Видалити обліковий запис користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="323"/>
         <source>Select user</source>
-        <translation type="unfinished"/>
+        <translation>Вибір користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="339"/>
@@ -98,43 +98,43 @@
         <location filename="../mainwindow.ui" line="1438"/>
         <location filename="../mainwindow.ui" line="1463"/>
         <source>Select user to delete</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть користувача для видалення</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="348"/>
         <source>User to delete:</source>
-        <translation type="unfinished"/>
+        <translation>Користувач для видалення:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="364"/>
         <source>Also delete the user&apos;s home directory</source>
-        <translation type="unfinished"/>
+        <translation>Також видалити домашній каталог користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="367"/>
         <source>Delete user home directory</source>
-        <translation type="unfinished"/>
+        <translation>Видалити домашній каталог користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="386"/>
         <source>Rename User Account</source>
-        <translation type="unfinished"/>
+        <translation>Перейменувати обліковий запис користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="398"/>
         <location filename="../mainwindow.ui" line="560"/>
         <source>Select user to modify:</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть користувача для зміни:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="440"/>
         <source>New user name:</source>
-        <translation type="unfinished"/>
+        <translation>Нове ім&apos;я користувача:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="481"/>
         <source>Change User Password</source>
-        <translation type="unfinished"/>
+        <translation>Змінити пароль користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="509"/>
@@ -144,17 +144,17 @@
     <message>
         <location filename="../mainwindow.ui" line="525"/>
         <source>Confirm new password:</source>
-        <translation type="unfinished"/>
+        <translation>Підтвердити новий пароль:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="544"/>
         <source>confirm new password</source>
-        <translation type="unfinished"/>
+        <translation>підтвердити новий пароль</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="576"/>
         <source>New user password:</source>
-        <translation type="unfinished"/>
+        <translation>Новий пароль користувача:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="610"/>
@@ -164,30 +164,30 @@
     <message>
         <location filename="../mainwindow.ui" line="613"/>
         <source>Repair a user configuration</source>
-        <translation type="unfinished"/>
+        <translation>Відновлення конфігурації користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="647"/>
         <location filename="../mainwindow.ui" line="1363"/>
         <source>Modify User Account</source>
-        <translation type="unfinished"/>
+        <translation>Змінити обліковий запис користувача</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="659"/>
         <location filename="../mainwindow.ui" line="675"/>
         <source>Select user to repair</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть користувача для виправлення</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="662"/>
         <location filename="../mainwindow.ui" line="1447"/>
         <source>User to change:</source>
-        <translation type="unfinished"/>
+        <translation>Користувач для зміни:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="707"/>
         <source>Restore Defaults</source>
-        <translation type="unfinished"/>
+        <translation>Скинути на типові значення</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="728"/>
@@ -197,7 +197,7 @@
     <message>
         <location filename="../mainwindow.ui" line="734"/>
         <source>Mozilla (Iceweasel or Firefox) configs</source>
-        <translation type="unfinished"/>
+        <translation>Конфігурації Mozilla (Iceweasel або Firefox).</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="737"/>
@@ -212,7 +212,7 @@
     <message>
         <location filename="../mainwindow.ui" line="750"/>
         <source>Group memberships</source>
-        <translation type="unfinished"/>
+        <translation>Членство в групах</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="753"/>
@@ -222,49 +222,49 @@
     <message>
         <location filename="../mainwindow.ui" line="763"/>
         <source>Change Autologin Settings</source>
-        <translation type="unfinished"/>
+        <translation>Змінити налаштування автовходу</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="769"/>
         <source>Log in automatically</source>
-        <translation type="unfinished"/>
+        <translation>Входити автоматично</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="776"/>
         <source>Require password to log in</source>
-        <translation type="unfinished"/>
+        <translation>Вимагати пароль для входу</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="791"/>
         <source>Copy/Sync</source>
-        <translation type="unfinished"/>
+        <translation>Копіювати/синхронізація</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="818"/>
         <source>Copy Between Desktops</source>
-        <translation type="unfinished"/>
+        <translation>Копіювати між стільницями</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="845"/>
         <location filename="../mainwindow.ui" line="912"/>
         <source>Select desktop to copy from</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть стільницю для копіювання</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="858"/>
         <source>Select to only copy files</source>
-        <translation type="unfinished"/>
+        <translation>Обрати лише копіювання файлів</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="861"/>
         <source>Copy only</source>
-        <translation type="unfinished"/>
+        <translation>Лише копіювання</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="877"/>
         <location filename="../mainwindow.ui" line="890"/>
         <source>Select desktop to copy to</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть стільницю для копіювання</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="899"/>
@@ -274,73 +274,73 @@
     <message>
         <location filename="../mainwindow.ui" line="921"/>
         <source>Copy from:</source>
-        <translation type="unfinished"/>
+        <translation>Копіювати з:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="934"/>
         <source>Select to copy and then delete differences</source>
-        <translation type="unfinished"/>
+        <translation>Оберіть, щоб скопіювати, а потім видалити відмінності</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="937"/>
         <source>Sync</source>
-        <translation type="unfinished"/>
+        <translation>Синхронізувати</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="983"/>
         <source>Select to copy/sync Shared</source>
-        <translation type="unfinished"/>
+        <translation>Оберіть для копіювання/синхронізації спільних ресурсів</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="986"/>
         <source>Shared folder</source>
-        <translation type="unfinished"/>
+        <translation>Спільний каталог</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="999"/>
         <source>Select to copy/sync entire home</source>
-        <translation type="unfinished"/>
+        <translation>Оберіть, щоб скопіювати/синхронізувати весь домашній каталог</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1002"/>
         <source>Entire home</source>
-        <translation type="unfinished"/>
+        <translation>Увесь домашній каталог</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1018"/>
         <source>Select to copy/sync the browser configuration</source>
-        <translation type="unfinished"/>
+        <translation>Оберіть, щоб скопіювати/синхронізувати конфігурацію браузера</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1021"/>
         <source>Mozilla (Firefox or Iceweasel) configs</source>
-        <translation type="unfinished"/>
+        <translation>Конфігурації Mozilla (Firefox або Iceweasel).</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1034"/>
         <source>Select to copy/sync Documents</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть для копіювання/синхронізації документів</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1037"/>
         <source>Documents folder</source>
-        <translation type="unfinished"/>
+        <translation>Каталог документів</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1044"/>
         <source>What to copy/sync:</source>
-        <translation type="unfinished"/>
+        <translation>Що копіювати/синхронізувати:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1060"/>
         <source>Progress</source>
-        <translation type="unfinished"/>
+        <translation>Перебіг</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1090"/>
         <location filename="../mainwindow.ui" line="1106"/>
         <source>Status of the changes</source>
-        <translation type="unfinished"/>
+        <translation>Стан змін</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1109"/>
@@ -350,52 +350,52 @@
     <message>
         <location filename="../mainwindow.ui" line="1125"/>
         <source>Progress of the changes</source>
-        <translation type="unfinished"/>
+        <translation>Перебіг змін</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1162"/>
         <source>Add/Remove Groups</source>
-        <translation type="unfinished"/>
+        <translation>Додати/видалити групи</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1174"/>
         <source>Add Group</source>
-        <translation type="unfinished"/>
+        <translation>Додати групу</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1204"/>
         <source>Group name:</source>
-        <translation type="unfinished"/>
+        <translation>Назва групи:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1226"/>
         <source>groupname</source>
-        <translation type="unfinished"/>
+        <translation>назвагрупи</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1258"/>
         <source>Delete Group</source>
-        <translation type="unfinished"/>
+        <translation>Видалити групу</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1320"/>
         <source>Group to delete:</source>
-        <translation type="unfinished"/>
+        <translation>Група для видалення:</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1351"/>
         <source>Group Membership</source>
-        <translation type="unfinished"/>
+        <translation>Членство в групі</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1470"/>
         <source>Groups user belongs to (change the groups by selecting/deselecting the appropriate boxes):</source>
-        <translation type="unfinished"/>
+        <translation>Групи, до яких належить користувач (змініть групи, встановивши/знявши прапорці):</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1490"/>
         <source>*Please doublecheck your selections before applying, assigning wrong group memberships can break your system.  Use Repair tab to restore the original memberships if you made a mistake.</source>
-        <translation type="unfinished"/>
+        <translation>*Будь ласка, ще раз перевірте свій вибір перед подачею заявки, призначення неправильного членства в групі може зруйнувати вашу систему. Використовуйте вкладку «Відновити», щоб відновити початкове членство, якщо ви зробили помилку.</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1550"/>
@@ -479,7 +479,7 @@
         <location filename="../mainwindow.cpp" line="946"/>
         <location filename="../mainwindow.cpp" line="951"/>
         <source>none</source>
-        <translation type="unfinished"/>
+        <translation>нічого</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="141"/>
@@ -487,75 +487,76 @@
         <location filename="../mainwindow.cpp" line="833"/>
         <location filename="../mainwindow.cpp" line="841"/>
         <source>browse...</source>
-        <translation type="unfinished"/>
+        <translation>огляд...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="213"/>
         <source>The user configuration will be repaired. Please close all other applications now. When finished, please logout or reboot. Are you sure you want to repair now?</source>
-        <translation type="unfinished"/>
+        <translation>Конфігурацію користувача буде виправлено. Закрийте всі інші програми. Після завершення вийдіть або перезавантажте систему. Ви впевнені, що хочете виправити її зараз?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="233"/>
         <source>User group membership was restored.</source>
-        <translation type="unfinished"/>
+        <translation>Членство в групі користувачів відновлено.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="239"/>
         <source>Mozilla settings were reset.</source>
-        <translation type="unfinished"/>
+        <translation>Налаштування Mozilla скинуто.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="248"/>
         <location filename="../mainwindow.cpp" line="257"/>
         <source>Autologin options</source>
-        <translation type="unfinished"/>
+        <translation>Опції автоматичного входу</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="249"/>
         <source>Autologin has been disabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished"/>
+        <translation>Автоматичний вхід вимкнено для облікового запису «%1».</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="258"/>
         <source>Autologin has been enabled for the &apos;%1&apos; account.</source>
-        <translation type="unfinished"/>
+        <translation>Для облікового запису «%1» увімкнено автоматичний вхід.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="269"/>
         <source>You must specify a &apos;copy to&apos; destination. You cannot copy to the desktop you are logged in to.</source>
-        <translation type="unfinished"/>
+        <translation>Ви повинні вказати пункт призначення дії «копіювати». Ви не можете скопіювати на стільницю, на якому ви ввійшли.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="273"/>
         <source>Before copying, close all other applications. Be sure the copy to destination is large enough to contain the files you are copying. Copying between desktops may overwrite or delete your files or preferences on the destination desktop. Are you sure you want to proceed?</source>
-        <translation type="unfinished"/>
+        <translation>Перед копіюванням закрийте всі інші програми. Переконайтеся, що місце призначення копії достатньо велике, щоб умістити файли, які ви копіюєте. Копіювання між стільницями може перезаписати або видалити ваші файли чи налаштування на стільниці призначення. Ви впевнені, що бажаєте продовжити?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="295"/>
         <source>Synchronizing desktop...</source>
-        <translation type="unfinished"/>
+        <translation>Синхронізація стільниць...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="297"/>
         <source>Copying desktop...</source>
-        <translation type="unfinished"/>
+        <translation>Копіювання стільниці...</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="324"/>
         <location filename="../mainwindow.cpp" line="495"/>
         <source>The user name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished"/>
+        <translation>Ім&apos;я користувача має містити принаймні 2 символи. Перш ніж продовжити, виберіть довшу назву.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="328"/>
         <source>The user name cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished"/>
+        <translation>Ім&apos;я користувача не може містити спеціальні символи або пробіли.
+Перш ніж продовжити, виберіть інше ім’я.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="336"/>
         <source>Sorry, this name is in use. Please enter a different name.</source>
-        <translation type="unfinished"/>
+        <translation>Це ім&apos;я вже використовується. Введіть інше ім&apos;я.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="340"/>
@@ -567,17 +568,17 @@ Please choose another name before proceeding.</source>
         <location filename="../mainwindow.cpp" line="345"/>
         <location filename="../mainwindow.cpp" line="376"/>
         <source>Password needs to be at least 2 characters long. Please enter a longer password before proceeding.</source>
-        <translation type="unfinished"/>
+        <translation>Пароль має бути не менше 2 символів. Перш ніж продовжити, введіть довший пароль.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="360"/>
         <source>The user was added ok.</source>
-        <translation type="unfinished"/>
+        <translation>Користувача додано успішно.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="363"/>
         <source>Failed to add the user.</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося додати користувача.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="388"/>
@@ -587,7 +588,7 @@ Please choose another name before proceeding.</source>
     <message>
         <location filename="../mainwindow.cpp" line="391"/>
         <source>Failed to change password.</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося змінити пароль.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="397"/>
@@ -602,39 +603,41 @@ Please choose another name before proceeding.</source>
     <message>
         <location filename="../mainwindow.cpp" line="409"/>
         <source>Failed to delete the user.</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося видалити користувача.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="422"/>
         <source>The group name needs to be at least 2 characters long. Please select a longer name before proceeding.</source>
-        <translation type="unfinished"/>
+        <translation>Назва групи має містити принаймні 2 символи. Перш ніж продовжити, виберіть довшу назву.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="426"/>
         <source>The group name needs to be lower case and it 
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished"/>
+        <translation>Назва групи має бути написана малими буквами
+не може містити спеціальних символів або пробілів.
+Перш ніж продовжити, виберіть іншу назву.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="435"/>
         <source>Sorry, that group name already exists. Please enter a different name.</source>
-        <translation type="unfinished"/>
+        <translation>Така назва групи вже існує. Будь ласка, введіть іншу назву</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="441"/>
         <source>The system group was added ok.</source>
-        <translation type="unfinished"/>
+        <translation>Системну групу додано успішно.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="443"/>
         <source>Failed to add the system group.</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося додати системну групу.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="445"/>
         <source>This action cannot be undone. Are you sure you want to delete group %1?</source>
-        <translation type="unfinished"/>
+        <translation>Цю дію не можна скасувати. Ви впевнені, що бажаєте видалити групу %1?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="451"/>
@@ -644,86 +647,88 @@ Please choose another name before proceeding.</source>
     <message>
         <location filename="../mainwindow.cpp" line="453"/>
         <source>Failed to delete the group.</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося видалити групу.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="472"/>
         <source>The changes have been applied.</source>
-        <translation type="unfinished"/>
+        <translation>Зміни застосовано.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="474"/>
         <source>Failed to apply group changes</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося застосувати зміни групи</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="486"/>
         <source>The selected user name is currently in use.</source>
-        <translation type="unfinished"/>
+        <translation>Вибране ім&apos;я користувача зараз використовується.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="487"/>
         <source>To rename this user, please log out and log back in using another user account.</source>
-        <translation type="unfinished"/>
+        <translation>Щоб перейменувати цього користувача, будь ласка, вийдіть із системи та увійдіть знову, використовуючи інший обліковий запис користувача.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="499"/>
         <source>The user name needs to be lower case and it
 cannot contain special characters or spaces.
 Please choose another name before proceeding.</source>
-        <translation type="unfinished"/>
+        <translation>Ім’я користувача має бути написане малими буквами
+не може містити спеціальних символів або пробілів.
+Перш ніж продовжити, виберіть інше ім’я.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="508"/>
         <source>Sorry, this name already exists on your system. Please enter a different name.</source>
-        <translation type="unfinished"/>
+        <translation>На жаль, це ім&apos;я вже існує у вашій системі. Будь ласка, введіть інше ім&apos;я.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="516"/>
         <source>Failed to rename the user. Please make sure that the user is not logged in, you might need to restart</source>
-        <translation type="unfinished"/>
+        <translation>Не вдалося перейменувати користувача. Будь ласка, переконайтеся, що користувач не ввійшов у систему, можливо, вам знадобиться перезапустити</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="535"/>
         <source>The user was renamed.</source>
-        <translation type="unfinished"/>
+        <translation>Користувача було перейменовано.</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="547"/>
         <location filename="../mainwindow.cpp" line="576"/>
         <source>Synchronizing desktop...ok</source>
-        <translation type="unfinished"/>
+        <translation>Синхронізація стільниці... виконано</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="549"/>
         <location filename="../mainwindow.cpp" line="578"/>
         <source>Copying desktop...ok</source>
-        <translation type="unfinished"/>
+        <translation>Копіювання стільниці... виконано</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="581"/>
         <source>Synchronizing desktop...failed</source>
-        <translation type="unfinished"/>
+        <translation>Синхронізація стільниці...не вдалося</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="583"/>
         <source>Copying desktop...failed</source>
-        <translation type="unfinished"/>
+        <translation>Копіювання стільниці... не вдалося</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="599"/>
         <source>Confirmation</source>
-        <translation type="unfinished"/>
+        <translation>Підтвердження</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="600"/>
         <source>Process not done. Are you sure you want to quit the application?</source>
-        <translation type="unfinished"/>
+        <translation>Процес не виконано. Ви впевнені, що бажаєте вийти з програми?</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="790"/>
         <source>About %1</source>
-        <translation type="unfinished"/>
+        <translation>Про %1</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="791"/>
@@ -743,17 +748,17 @@ Please choose another name before proceeding.</source>
     <message>
         <location filename="../mainwindow.cpp" line="795"/>
         <source>%1 License</source>
-        <translation type="unfinished"/>
+        <translation>%1 Ліцензія</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="809"/>
         <source>%1 Help</source>
-        <translation type="unfinished"/>
+        <translation>%1 Довідка</translation>
     </message>
     <message>
         <location filename="../mainwindow.cpp" line="834"/>
         <source>Select folder to copy to</source>
-        <translation type="unfinished"/>
+        <translation>Виберіть каталог для копіювання</translation>
     </message>
 </context>
 <context>
@@ -787,7 +792,7 @@ Please choose another name before proceeding.</source>
     <message>
         <location filename="../main.cpp" line="55"/>
         <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
-        <translation type="unfinished"/>
+        <translation>Здається, ви ввійшли як root, вийдіть із системи та увійдіть як звичайний користувач, щоб використовувати цю програму.</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
